@@ -4,6 +4,7 @@ from enum import Enum
 class Currency(Enum):
     USD = 1
     RUB = 2
+    EUR = 3
 
     @staticmethod
     def parse(strval: str):
@@ -11,6 +12,8 @@ class Currency(Enum):
             return Currency.USD
         if strval in {'₽', 'RUB'}:
             return Currency.RUB
+        if strval in {'€', 'EUR'}:
+            return Currency.EUR
         raise ValueError(strval)
 
     def __str__(self):
@@ -18,4 +21,6 @@ class Currency(Enum):
             return '$'
         elif self == Currency.RUB:
             return '₽'
+        elif self == Currency.EUR:
+            return '€'
         return self.__repr__(self)
